==> func_adl_servicex_xaodr22-1.1.4.22.2.113-py3-none-any.whl: func_adl_servicex_xaodr22/xAOD/jemroi_v1.py <==
from __future__ import annotations
import ast
from typing import Tuple, TypeVar, Iterable
from func_adl import ObjectStream, func_adl_callback, func_adl_parameterized_call
import func_adl_servicex_xaodr22

_method_map = {
    'roiWord': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JEMRoI_v1',
        'method_name': 'roiWord',
        'return_type': 'unsigned int',
    },
    'crate': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JEMRoI_v1',
        'method_name': 'crate',
        'return_type': 'int',
    },
    'jem': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JEMRoI_v1',
        'method_name': 'jem',
        'return_type': 'int',
    },
    'frame': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JEMRoI_v1',
        'method_name': 'frame',
        'return_type': 'int',
    },
    'location': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JEMRoI_v1',
        'method_name': 'location',
        'return_type': 'int',
    },
    'forward': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JEMRoI_v1',
        'method_name': 'forward',
        'return_type': 'int',
    },
    'hits': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JEMRoI_v1',
        'method_name': 'hits',
        'return_type': 'int',
    },
    'error': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JEMRoI_v1',
        'method_name': 'error',
        'return_type': 'int',
    },
    'parity': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JEMRoI_v1',
        'method_name': 'parity',
        'return_type': 'int',
    },
    'saturation': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JEMRoI_v1',
        'method_name': 'saturation',
        'return_type': 'int',
    },
    'index': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JEMRoI_v1',
        'method_name': 'index',
        'return_type': 'int',
    },
    'usingPrivateStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JEMRoI_v1',
        'method_name': 'usingPrivateStore',
        'return_type': 'bool',
    },
    'usingStandaloneStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JEMRoI_v1',
        'method_name': 'usingStandaloneStore',
        'return_type': 'bool',
    },
    'hasStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JEMRoI_v1',
        'method_name': 'hasStore',
        'return_type': 'bool',
    },
    'hasNonConstStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JEMRoI_v1',
        'method_name': 'hasNonConstStore',
        'return_type': 'bool',
    },
    'clearDecorations': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JEMRoI_v1',
        'method_name': 'clearDecorations',
        'return_type': 'bool',
    },
    'trackIndices': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JEMRoI_v1',
        'method_name': 'trackIndices',
        'return_type': 'bool',
    },
    'auxdataConst': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JEMRoI_v1',
        'method_name': 'auxdataConst',
        'return_type': 'U',
    },
    'isAvailable': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JEMRoI_v1',
        'method_name': 'isAvailable',
        'return_type': 'bool',
    },
}


T = TypeVar('T')


def _add_method_metadata(s: ObjectStream[T], a: ast.Call) -> Tuple[ObjectStream[T], ast.Call]:
    '''Add metadata for a collection to the func_adl stream if we know about it
    '''
    assert isinstance(a.func, ast.Attribute)
    if a.func.attr in _method_map:
        s_update = s.MetaData(_method_map[a.func.attr])
        s_update = s_update.MetaData({
            'metadata_type': 'inject_code',
            'name': 'xAODTrigL1Calo/versions/JEMRoI_v1.h',
            'body_includes': ["xAODTrigL1Calo/versions/JEMRoI_v1.h"],
        })
        return s_update, a
    else:
        return s, a


@func_adl_callback(_add_method_metadata)
class JEMRoI_v1:
    "A class"

    def roiWord(self) -> int:
        "A method"
        ...

    def crate(self) -> int:
        "A method"
        ...

    def jem(self) -> int:
        "A method"
        ...

    def frame(self) -> int:
        "A method"
        ...

    def location(self) -> int:
        "A method"
        ...

    def forward(self) -> int:
        "A method"
        ...

    def hits(self) -> int:
        "A method"
        ...

    def error(self) -> int:
        "A method"
        ...

    def parity(self) -> int:
        "A method"
        ...

    def saturation(self) -> int:
        "A method"
        ...

    def index(self) -> int:
        "A method"
        ...

    def usingPrivateStore(self) -> bool:
        "A method"
        ...

    def usingStandaloneStore(self) -> bool:
        "A method"
        ...

    def hasStore(self) -> bool:
        "A method"
        ...

    def hasNonConstStore(self) -> bool:
        "A method"
        ...

    def clearDecorations(self) -> bool:
        "A method"
        ...

    def trackIndices(self) -> bool:
        "A method"
        ...

    @func_adl_parameterized_call(lambda s, a, param_1: func_adl_servicex_xaodr22.type_support.cpp_generic_1arg_callback('auxdataConst', s, a, param_1))
    @property
    def auxdataConst(self) -> func_adl_servicex_xaodr22.type_support.index_type_forwarder[str]:
        "A method"
        ...

    @func_adl_parameterized_call(lambda s, a, param_1: func_adl_servicex_xaodr22.type_support.cpp_generic_1arg_callback('isAvailable', s, a, param_1))
    @property
    def isAvailable(self) -> func_adl_servicex_xaodr22.type_support.index_type_forwarder[str]:
        "A method"
        ...

==> func_adl_servicex_xaodr22-2.0.1.22.2.107-py3-none-any.whl: func_adl_servicex_xaodr22/xAOD/jemroi_v1.py <==
from __future__ import annotations
import ast
from typing import Tuple, TypeVar, Iterable
from func_adl import ObjectStream, func_adl_callback, func_adl_parameterized_call
from enum import Enum
import func_adl_servicex_xaodr22

_method_map = {
    'roiWord': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JEMRoI_v1',
        'method_name': 'roiWord',
        'return_type': 'unsigned int',
    },
    'crate': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JEMRoI_v1',
        'method_name': 'crate',
        'return_type': 'int',
    },
    'jem': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JEMRoI_v1',
        'method_name': 'jem',
        'return_type': 'int',
    },
    'frame': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JEMRoI_v1',
        'method_name': 'frame',
        'return_type': 'int',
    },
    'location': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JEMRoI_v1',
        'method_name': 'location',
        'return_type': 'int',
    },
    'forward': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JEMRoI_v1',
        'method_name': 'forward',
        'return_type': 'int',
    },
    'hits': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JEMRoI_v1',
        'method_name': 'hits',
        'return_type': 'int',
    },
    'error': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JEMRoI_v1',
        'method_name': 'error',
        'return_type': 'int',
    },
    'parity': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JEMRoI_v1',
        'method_name': 'parity',
        'return_type': 'int',
    },
    'saturation': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JEMRoI_v1',
        'method_name': 'saturation',
        'return_type': 'int',
    },
    'index': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JEMRoI_v1',
        'method_name': 'index',
        'return_type': 'int',
    },
    'usingPrivateStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JEMRoI_v1',
        'method_name': 'usingPrivateStore',
        'return_type': 'bool',
    },
    'usingStandaloneStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JEMRoI_v1',
        'method_name': 'usingStandaloneStore',
        'return_type': 'bool',
    },
    'hasStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JEMRoI_v1',
        'method_name': 'hasStore',
        'return_type': 'bool',
    },
    'hasNonConstStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JEMRoI_v1',
        'method_name': 'hasNonConstStore',
        'return_type': 'bool',
    },
    'clearDecorations': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JEMRoI_v1',
        'method_name': 'clearDecorations',
        'return_type': 'bool',
    },
    'trackIndices': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JEMRoI_v1',
        'method_name': 'trackIndices',
        'return_type': 'bool',
    },
    'auxdataConst': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JEMRoI_v1',
        'method_name': 'auxdataConst',
        'return_type': 'U',
    },
    'isAvailable': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JEMRoI_v1',
        'method_name': 'isAvailable',
        'return_type': 'bool',
    },
}

_enum_map = {      
}

T = TypeVar('T')


def _add_method_metadata(s: ObjectStream[T], a: ast.Call) -> Tuple[ObjectStream[T], ast.Call]:
    '''Add metadata for a collection to the func_adl stream if we know about it
    '''
    assert isinstance(a.func, ast.Attribute)
    if a.func.attr in _method_map:
        s_update = s.MetaData(_method_map[a.func.attr])
        s_update = s_update.MetaData({
            'metadata_type': 'inject_code',
            'name': 'xAODTrigL1Calo/versions/JEMRoI_v1.h',
            'body_includes': ["xAODTrigL1Calo/versions/JEMRoI_v1.h"],
        })
        for md in _enum_map.get(a.func.attr, []):
            s_update = s_update.MetaData(md)
        return s_update, a
    else:
        return s, a


@func_adl_callback(_add_method_metadata)
class JEMRoI_v1:
    "A class"


    def roiWord(self) -> int:
        "A method"
        ...

    def crate(self) -> int:
        "A method"
        ...

    def jem(self) -> int:
        "A method"
        ...

    def frame(self) -> int:
        "A method"
        ...

    def location(self) -> int:
        "A method"
        ...

    def forward(self) -> int:
        "A method"
        ...

    def hits(self) -> int:
        "A method"
        ...

    def error(self) -> int:
        "A method"
        ...

    def parity(self) -> int:
        "A method"
        ...

    def saturation(self) -> int:
        "A method"
        ...

    def index(self) -> int:
        "A method"
        ...

    def usingPrivateStore(self) -> bool:
        "A method"
        ...

    def usingStandaloneStore(self) -> bool:
        "A method"
        ...

    def hasStore(self) -> bool:
        "A method"
        ...

    def hasNonConstStore(self) -> bool:
        "A method"
        ...

    def clearDecorations(self) -> bool:
        "A method"
        ...

    def trackIndices(self) -> bool:
        "A method"
        ...

    @func_adl_parameterized_call(lambda s, a, param_1: func_adl_servicex_xaodr22.type_support.cpp_generic_1arg_callback('auxdataConst', s, a, param_1))
    @property
    def auxdataConst(self) -> func_adl_servicex_xaodr22.type_support.index_type_forwarder[func_adl_servicex_xaodr22.str.str]:
        "A method"
        ...

    @func_adl_parameterized_call(lambda s, a, param_1: func_adl_servicex_xaodr22.type_support.cpp_generic_1arg_callback('isAvailable', s, a, param_1))
    @property
    def isAvailable(self) -> func_adl_servicex_xaodr22.type_support.index_type_forwarder[func_adl_servicex_xaodr22.str.str]:
        "A method"
        ...
